@@ -21,19 +21,27 @@ test_that("can work with with Date `.i`", {
 })
 
 test_that(".x must be the same size as .i", {
-  expect_error(hop_index(1, 1:2, 1, 1, identity), class = "slider_error_index_incompatible_size")
+  expect_snapshot({
+    (expect_error(hop_index(1, 1:2, 1, 1, identity), class = "slider_error_index_incompatible_size"))
+  })
 })
 
 test_that(".i must be ascending", {
-  expect_error(hop_index(1:2, 2:1, 1:2, 1:2, identity), class = "slider_error_index_must_be_ascending")
+  expect_snapshot({
+    (expect_error(hop_index(1:2, 2:1, 1:2, 1:2, identity), class = "slider_error_index_must_be_ascending"))
+  })
 })
 
 test_that(".starts must be ascending", {
-  expect_error(hop_index(1:2, 1:2, 2:1, 1:2, identity), class = "slider_error_endpoints_must_be_ascending")
+  expect_snapshot({
+    (expect_error(hop_index(1:2, 1:2, 2:1, 1:2, identity), class = "slider_error_endpoints_must_be_ascending"))
+  })
 })
 
 test_that(".stops must be ascending", {
-  expect_error(hop_index(1:2, 1:2, 1:2, 2:1, identity), class = "slider_error_endpoints_must_be_ascending")
+  expect_snapshot({
+    (expect_error(hop_index(1:2, 1:2, 1:2, 2:1, identity), class = "slider_error_endpoints_must_be_ascending"))
+  })
 })
 
 test_that("empty input returns a list, but after the index size check", {
@@ -46,23 +54,31 @@ test_that("empty `.x` and `.i`, but size `n > 0` `.starts` and `.stops` returns
 })
 
 test_that("empty `.x` and `.i`, but size `n > 0` `.starts` and `.stops`: sizes and types are checked first", {
-  expect_error(hop_index(integer(), integer(), 1:3, 1:2, ~.x), class = "vctrs_error_incompatible_size")
-  expect_error(hop_index(integer(), integer(), 1, "x", ~.x), class = "vctrs_error_incompatible_type")
+  expect_snapshot({
+    (expect_error(hop_index(integer(), integer(), 1:3, 1:2, ~.x), class = "vctrs_error_incompatible_size"))
+    (expect_error(hop_index(integer(), integer(), 1, "x", ~.x), class = "vctrs_error_incompatible_type"))
+  })
 })
 
 test_that(".i must not contain NA values", {
-  expect_error(hop_index(1:2, c(1, NA), 1:2, 1:2, identity), class = "slider_error_index_cannot_be_na")
-  expect_error(hop_index(1:2, c(NA, 1), 1:2, 1:2, identity), class = "slider_error_index_cannot_be_na")
+  expect_snapshot({
+    (expect_error(hop_index(1:2, c(1, NA), 1:2, 1:2, identity), class = "slider_error_index_cannot_be_na"))
+    (expect_error(hop_index(1:2, c(NA, 1), 1:2, 1:2, identity), class = "slider_error_index_cannot_be_na"))
+  })
 })
 
 test_that(".starts must not contain NA values", {
-  expect_error(hop_index(1:2, 1:2, c(1, NA), 1:2, identity), class = "slider_error_endpoints_cannot_be_na")
-  expect_error(hop_index(1:2, 1:2, c(NA, 1), 1:2, identity), class = "slider_error_endpoints_cannot_be_na")
+  expect_snapshot({
+    (expect_error(hop_index(1:2, 1:2, c(1, NA), 1:2, identity), class = "slider_error_endpoints_cannot_be_na"))
+    (expect_error(hop_index(1:2, 1:2, c(NA, 1), 1:2, identity), class = "slider_error_endpoints_cannot_be_na"))
+  })
 })
 
 test_that(".stops must not contain NA values", {
-  expect_error(hop_index(1:2, 1:2, 1:2, c(1, NA), identity), class = "slider_error_endpoints_cannot_be_na")
-  expect_error(hop_index(1:2, 1:2, 1:2, c(NA, 1), identity), class = "slider_error_endpoints_cannot_be_na")
+  expect_snapshot({
+    (expect_error(hop_index(1:2, 1:2, 1:2, c(1, NA), identity), class = "slider_error_endpoints_cannot_be_na"))
+    (expect_error(hop_index(1:2, 1:2, 1:2, c(NA, 1), identity), class = "slider_error_endpoints_cannot_be_na"))
+  })
 })
 
 test_that("recycling is used for .starts/.stops", {
@@ -82,7 +98,9 @@ test_that("recycling is used for .starts/.stops", {
     )
   )
 
-  expect_error(hop_index(1:2, 1:2, 1:2, 1:3, ~.x), class = "vctrs_error_incompatible_size")
+  expect_snapshot({
+    (expect_error(hop_index(1:2, 1:2, 1:2, 1:3, ~.x), class = "vctrs_error_incompatible_size"))
+  })
 })
 
 test_that("0 length .starts/.stops are allowed", {
@@ -94,10 +112,12 @@ test_that(".starts and .stops are cast to .i", {
   starts <- c("x", "y")
   stops <- i
 
-  expect_error(
-    hop_index(1:2, i, starts, stops, ~.x),
-    class = "vctrs_error_incompatible_type"
-  )
+  expect_snapshot({
+    (expect_error(
+      hop_index(1:2, i, starts, stops, ~.x),
+      class = "vctrs_error_incompatible_type"
+    ))
+  })
 })
 
 test_that("output size is the common size of .starts/.stops", {
