@@ -15,24 +15,22 @@ test_that("phop_vec() can simplify automatically", {
 
 test_that("phop_vec() errors if it can't simplify", {
   fn <- function(x, y) if (x == 1L) {1} else {"hi"}
-  expect_error(
-    phop_vec(list(1:2, 1:2), 1:2, 1:2, fn, .ptype = NULL),
-    class = "vctrs_error_incompatible_type"
-  )
+  expect_snapshot({
+    (expect_error(
+      phop_vec(list(1:2, 1:2), 1:2, 1:2, fn, .ptype = NULL),
+      class = "vctrs_error_incompatible_type"
+    ))
+  })
 })
 
 # ------------------------------------------------------------------------------
 # .ptype
 
 test_that("`.ptype = NULL` validates that element lengths are 1", {
-  expect_error(
-    phop_vec(list(1:2, 1:2), 1:2, 1:2, ~if(.x == 1L) {1:2} else {1}, .ptype = NULL),
-    "In iteration 1, the result of `.f` had size 2, not 1."
-  )
-  expect_error(
-    phop_vec(list(1:2, 1:2), 1:2, 1:2, ~if(.x == 1L) {NULL} else {2}, .ptype = NULL),
-    "In iteration 1, the result of `.f` had size 0, not 1."
-  )
+  expect_snapshot({
+    (expect_error(phop_vec(list(1:2, 1:2), 1:2, 1:2, ~if(.x == 1L) {1:2} else {1}, .ptype = NULL)))
+    (expect_error(phop_vec(list(1:2, 1:2), 1:2, 1:2, ~if(.x == 1L) {NULL} else {2}, .ptype = NULL)))
+  })
 })
 
 test_that("`phop_vec()` falls back to `c()` method as required", {
